ShaderBundleBuildResult class final

Information about a shader bundle produced by buildShaderBundleJson.

Constructors

ShaderBundleBuildResult({required Uri outputFile, required String legacyAssetKey, String? dataAssetName, String? dataAssetId, String? flutterAssetKey})
const

Properties

dataAssetId String?
DataAsset package identifier, e.g. package:my_app/flutter_gpu_shaders/shaderbundles/materials.shaderbundle.
final
dataAssetName String?
DataAsset name registered for the generated bundle, when one was emitted.
final
flutterAssetKey String?
Flutter asset-bundle key for the DataAsset, when one was emitted.
final
hashCode int
The hash code for this object.
no setterinherited
legacyAssetKey String
Historical Flutter asset key for projects listing the generated file in flutter.assets.
final
outputFile Uri
Absolute file URI of the generated .shaderbundle.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited