legacyAssetKey property
Historical Flutter asset key for projects listing the generated file in
flutter.assets.
Implementation
final String legacyAssetKey;
Historical Flutter asset key for projects listing the generated file in
flutter.assets.
final String legacyAssetKey;