ShaderBundleAssetMode enum
Controls whether buildShaderBundleJson registers the produced shader bundle as a Dart DataAsset.
Values
- legacyOnly → const ShaderBundleAssetMode
-
Preserve the historical behavior: only write
build/shaderbundles/[name].shaderbundle. - dataAssetsIfAvailable → const ShaderBundleAssetMode
-
Register a DataAsset when the current Flutter/Dart build supports data assets, and otherwise silently fall back to legacyOnly.
- dataAssetsRequired → const ShaderBundleAssetMode
-
Require DataAssets support and fail the build with a targeted error when the current toolchain did not request data assets from the hook.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ShaderBundleAssetMode> - A constant List of the values in this enum, in order of their declaration.