environment library
Functions
-
findEngineArtifactsDir(
{String? dartPath}) → Uri - Locate the engine artifacts cache directory in the Flutter SDK.
-
findImpellerC(
) → Future< Uri> - Locate the ImpellerC offline shader compiler in the engine artifacts cach directory.